Installation
============

Installation using pip
----------------------

If you already have Python 3+ installed along with pip, then do::

    $ pip install beluga

Installation using binaries
---------------------------

Binary files are located on `PyPI <https://pypi.org/project/beluga/#history>`_ and `GitHub <https://github.com/Rapid-Design-of-Systems-Laboratory/beluga/releases>`_.
